from distutils.core import setup
setup(
  name = 'LogsHub',         # How you named your package folder (MyLib)
  packages = ['LogsHub'],   # Chose the same as "name"
  version = '1.0.16',      # Start with a small number and increase it with every change you make
  license='OpenSource',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Writing specific logs',   # Give a short description about your library
  author = 'Odai',                   # Type in your name
  author_email = 'o.3odai@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/Odai-Atef/logs_hub_python3',   # Provide either the link to your github or to your website
  install_requires=[            # I get to this in a second
          'python-decouple',
          'requests'
      ],
  entry_points={
    'console_scripts': ['LogsHub=LogsHub.logs_hub:main']
  },
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    # 'License ::  OpenSource',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)


import logging
from datetime import datetime
import json
from decouple import config
import requests

def main():
    return None
class logs_hub:


    def _log(self,msg, application, level,execution_time, user_id, extra_data):
        now =str( int(datetime.now().timestamp()))
        environment = 'development' if config("ENVIRONMENT") == None or config("ENVIRONMENT")=="" else config("ENVIRONMENT")
        data={
            "message": msg,
            "level": level,
            "application": application,
            "environment": environment,
            "user_id": user_id,
            "execution_time": execution_time,
            "extra_data": extra_data,
            "timestamp": now
        }
        logging.basicConfig(filename=now+'.log', filemode='w', format='%(message)s')
        logging.warning(json.dumps(data))
        return data
    
    def _notify(self,msg):
        url=config("NOTIFY_URL")
        requests.post(url, data = {"message": json.dumps(msg), "channel": msg['application']})


    def warning(self,msg, application, execution_time=None, user_id=None, extra_data=None):
        self._log(msg, application,config('WARNING') ,execution_time,  user_id, extra_data)
        
    def info(self,msg, application, execution_time=None, user_id=None, extra_data=None):
        self._log(msg, application,config('INFO') ,execution_time,  user_id, extra_data) 

    def error(self,msg, application, execution_time=None, user_id=None, extra_data=None):
        self._log(msg, application,config('ERROR') ,execution_time,  user_id, extra_data)      

    def critical(self,msg, application, execution_time=None, user_id=None, extra_data=None):
        self._notify(self._log(msg, application,config('CRITICAL') ,execution_time,  user_id, extra_data))

